@@ -10,7 +10,7 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 sub new {
     my $class = shift;
@@ -257,6 +257,7 @@ sub load {
         unless ( ref $plugin ) {
             if ( $plugin =~ /^:core$/i ) {
                 $self->load(
+                    'Ping',
                     'Join',
                     'Seen',
                     'Greeting',
@@ -464,6 +465,21 @@ sub list {
     }
 }
 
+sub health {
+    my ($self) = @_;
+
+    return {
+        nick    => $self->{nick},
+        server  => $self->{connect}{server},
+        port    => $self->{connect}{port},
+        ssl     => $self->{connect}{ssl},
+        spawn   => $self->{spawn},
+        hooks   => scalar( @{ $self->{hooks} } ),
+        ticks   => scalar( @{ $self->{ticks} } ),
+        plugins => scalar( keys %{ $self->{loaded} } ),
+    };
+}
+
 1;
 
 __END__
@@ -478,7 +494,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
@@ -1036,6 +1052,12 @@ and a list of items.
     $bot->list( ', ', 'and', 'Alpha', 'Beta' );
     # returns "Alpha and Beta"
 
+=head2 health
+
+This method returns a hashref of simple key value pairs for different "health"
+aspects (or current state) of the bot. It includes things like server and port
+connection, number of children, and so on.
+
 =head1 SEE ALSO
 
 You can look for additional information at:
